@@ -17,10 +17,8 @@ class Config:
 
     UPLOADED_PRODUCTPHOTOS_DEST = os.path.join(STATIC, "uploads", "products")
     UPLOADED_CATEGORYPHOTOS_DEST = os.path.join(STATIC, "uploads", "category")
-    UPLOADED_SUBCATEGORYPHOTOS_DEST = os.path.join(
-        STATIC, "uploads", "subcategory"
-    )
-    PASSWORD_SALT = 'abcdefghi'
+    UPLOADED_SUBCATEGORYPHOTOS_DEST = os.path.join(STATIC, "uploads", "subcategory")
+    PASSWORD_SALT = "abcdefghi"
 
 
 class DevelopmentConfig(Config):
@@ -28,7 +26,8 @@ class DevelopmentConfig(Config):
 
     ENV = "development"
     DEBUG = True
-    EXPLAIN_TEMPLATE_LOADING = True
+    # EXPLAIN_TEMPLATE_LOADING = True
+    # LOGIN_DISABLED = True
 
 
 class TestingConfig(Config):
