@@ -1,18 +1,18 @@
 def test_new_user(new_user):
-    assert new_user.username == "abcd"
+    assert new_user.email == "admin3@domain.com"
     assert new_user.password != "pass"
-    assert not new_user.admin_user
+    assert not new_user.is_admin
 
 
 def test_home_page(test_client):
     response = test_client.get("/")
-    assert response.status_code == 302  # redirect
+    assert response.status_code == 200
 
 
 def test_valid_login_logout(test_client, init_database):
     response = test_client.post(
         "/login/",
-        data=dict(username="car", password="pass"),
+        data=dict(email="admin1@domain.com", password="pass"),
         follow_redirects=True,
     )
     # print(response.data)
@@ -22,7 +22,7 @@ def test_valid_login_logout(test_client, init_database):
     # Control panel
     # response = test_client.get('/logout', follow_redirects=True)
     # assert response.status_code == 200
-def test_control_panel(test_client, init_database):
-#     response = test_client.get("/control_panel/", follow_redirects=True)
-#     print(response.data)
-#     assert response.status_code == 200
+
+
+def test_dashboard(test_client, init_database):
+    pass
