@@ -46,7 +46,7 @@ module_blueprint = globals()["{}_blueprint".format(module_info["module_name"])]
 module_name = module_info["module_name"]
 
 
-@module_blueprint.route(module_info["panel_redirect"])
+@module_blueprint.route(module_info["dashboard"])
 @login_required
 def dashboard():
     context = {}
@@ -117,9 +117,7 @@ def delete(name):
         return redirect(url_for("category.dashboard"))
 
 
-@module_blueprint.route(
-    "/<category_name>/img/<filename>/delete", methods=["GET"]
-)
+@module_blueprint.route("/<category_name>/img/<filename>/delete", methods=["GET"])
 @login_required
 def category_image_delete(category_name, filename):
     resource = Resource.query.filter(Resource.filename == filename).first()
@@ -127,9 +125,7 @@ def category_image_delete(category_name, filename):
     category.resources.remove(resource)
     category.update()
     delete_file(
-        os.path.join(
-            current_app.config["UPLOADED_CATEGORYPHOTOS_DEST"], filename
-        )
+        os.path.join(current_app.config["UPLOADED_CATEGORYPHOTOS_DEST"], filename)
     )
 
     return redirect(url_for("category.dashboard"))
@@ -168,16 +164,14 @@ def update():
             category.name = name
             category.update()
         except sqlalchemy.exc.IntegrityError:
-            context[
-                "message"
-            ] = "you cannot modify to an already existing category"
+            context["message"] = "you cannot modify to an already existing category"
             context["redirect_url"] = "/category/"
             render_template("category/message.html", **context)
         return redirect(url_for("category.dashboard"))
 
 
 @module_blueprint.route(
-    "{}/edit/<category_name>".format(module_info["panel_redirect"]),
+    "{}/edit/<category_name>".format(module_info["dashboard"]),
     methods=["GET", "POST"],
 )
 @login_required
@@ -203,7 +197,7 @@ def check(category_name):
 
 
 @module_blueprint.route(
-    "{}/<category_name>/sub/".format(module_info["panel_redirect"]),
+    "{}/<category_name>/sub/".format(module_info["dashboard"]),
     methods=["GET", "POST"],
 )
 @login_required
@@ -216,7 +210,7 @@ def manage_sub(category_name):
 
 
 @module_blueprint.route(
-    "{}/<category_name>/sub/add".format(module_info["panel_redirect"]),
+    "{}/<category_name>/sub/add".format(module_info["dashboard"]),
     methods=["GET", "POST"],
 )
 @login_required
@@ -245,9 +239,7 @@ def add_sub(category_name):
                 )
             )
 
-        category = Category.query.filter(
-            Category.name == category_name
-        ).first()
+        category = Category.query.filter(Category.name == category_name).first()
         subcategory = SubCategory(name=name)
 
         try:
@@ -270,13 +262,11 @@ def add_sub(category_name):
         category.subcategories.append(subcategory)
 
         category.update()
-        return redirect(
-            url_for("category.manage_sub", category_name=category_name)
-        )
+        return redirect(url_for("category.manage_sub", category_name=category_name))
 
 
 @module_blueprint.route(
-    "{}/sub/<subcategory_id>/img/edit".format(module_info["panel_redirect"]),
+    "{}/sub/<subcategory_id>/img/edit".format(module_info["dashboard"]),
     methods=["GET", "POST"],
 )
 @login_required
@@ -287,9 +277,7 @@ def edit_sub_img_dashboard(subcategory_id):
     return render_template("category/edit_img_sub.html", **context)
 
 
-@module_blueprint.route(
-    "/sub/<subcategory_id>/name/edit", methods=["GET", "POST"]
-)
+@module_blueprint.route("/sub/<subcategory_id>/name/edit", methods=["GET", "POST"])
 @login_required
 def edit_sub_name(subcategory_id):
     if request.method == "POST":
@@ -319,15 +307,11 @@ def edit_sub_name(subcategory_id):
         subcategory.update()
         flash(notify_success("Subcategory name updated successfully!"))
         return redirect(
-            url_for(
-                "category.manage_sub", category_name=subcategory.category.name
-            )
+            url_for("category.manage_sub", category_name=subcategory.category.name)
         )
 
 
-@module_blueprint.route(
-    "/sub/<subcategory_id>/img/edit", methods=["GET", "POST"]
-)
+@module_blueprint.route("/sub/<subcategory_id>/img/edit", methods=["GET", "POST"])
 @login_required
 def edit_sub_img(subcategory_id):
     if request.method == "POST":
@@ -357,9 +341,7 @@ def edit_sub_img(subcategory_id):
         )
 
 
-@module_blueprint.route(
-    "/sub/<subcategory_id>/img/<filename>/delete", methods=["GET"]
-)
+@module_blueprint.route("/sub/<subcategory_id>/img/<filename>/delete", methods=["GET"])
 @login_required
 def subcategory_image_delete(subcategory_id, filename):
     resource = Resource.query.filter(Resource.filename == filename).first()
@@ -367,21 +349,15 @@ def subcategory_image_delete(subcategory_id, filename):
     subcategory.resources.remove(resource)
     subcategory.update()
     delete_file(
-        os.path.join(
-            current_app.config["UPLOADED_SUBCATEGORYPHOTOS_DEST"], filename
-        )
+        os.path.join(current_app.config["UPLOADED_SUBCATEGORYPHOTOS_DEST"], filename)
     )
 
     return redirect(
-        url_for(
-            "category.edit_sub_img_dashboard", subcategory_id=subcategory_id
-        )
+        url_for("category.edit_sub_img_dashboard", subcategory_id=subcategory_id)
     )
 
 
-@module_blueprint.route(
-    "/sub/<subcategory_id>/delete", methods=["GET", "POST"]
-)
+@module_blueprint.route("/sub/<subcategory_id>/delete", methods=["GET", "POST"])
 @login_required
 def sub_delete(subcategory_id):
     subcategory = SubCategory.query.get(subcategory_id)
@@ -395,9 +371,7 @@ def sub_delete(subcategory_id):
                 "Cannot delete subcategory uncategorised of catgeory uncategorised"
             )
         )
-        return redirect(
-            url_for("category.manage_sub", category_name=category_name)
-        )
+        return redirect(url_for("category.manage_sub", category_name=category_name))
 
     uncategorised_sub = SubCategory.query.filter(
         (SubCategory.name == "uncategorised")
@@ -421,13 +395,11 @@ def sub_delete(subcategory_id):
     # subcategory.delete()
 
     ## add for products change
-    return redirect(
-        url_for("category.manage_sub", category_name=category_name)
-    )
+    return redirect(url_for("category.manage_sub", category_name=category_name))
 
 
 @module_blueprint.route(
-    "<category_id>/{}/sub".format(module_info["panel_redirect"]),
+    "<category_id>/{}/sub".format(module_info["dashboard"]),
     methods=["GET", "POST"],
 )
 @login_required
@@ -446,7 +418,11 @@ def choose_sub_dashboard(category_id):
 
 @module_blueprint.route("/sub/file/<filename>", methods=["GET"])
 def subcategory_image(filename):
-
+    if filename == "default":
+        return send_from_directory(
+            os.path.join(current_app.config["BASE_DIR"], "static", "default"),
+            "default_subcategory.jpg",
+        )
     return send_from_directory(
         current_app.config["UPLOADED_SUBCATEGORYPHOTOS_DEST"], filename
     )
