@@ -1,3 +1,5 @@
+from datetime import datetime
+
 from shopyoapi.init import db
 
 
@@ -5,7 +7,11 @@ class Transaction(db.Model):
     __tablename__ = "transactions"
 
     id = db.Column(db.Integer, primary_key=True)
+
     chashier_id = db.Column(db.Integer)
+    time = db.Column(db.DateTime, default=datetime.now())
+    quantity = db.Column(db.Integer)
+    price = db.Column(db.Float)
 
     def add(self):
         db.session.add(self)
