@@ -8,6 +8,8 @@ import os
 from flask import Blueprint
 from flask import current_app
 from flask import render_template
+from flask import redirect
+from flask import url_for
 
 #
 # from shopyoapi.html import notify_success
@@ -15,6 +17,8 @@ from flask import render_template
 from shopyoapi.enhance import get_active_theme_dir
 from shopyoapi.enhance import get_setting
 
+from modules.shop.helpers import get_cart_data
+
 dirpath = os.path.dirname(os.path.abspath(__file__))
 module_info = {}
 
@@ -36,10 +40,12 @@ module_blueprint = globals()["{}_blueprint".format(module_info["module_name"])]
 @module_blueprint.route("/")
 def index():
     # cant be defined above but must be manually set each time
-    active_theme_dir = os.path.join(
-        dirpath, "..", "..", "themes", get_setting("ACTIVE_THEME")
-    )
-    module_blueprint.template_folder = active_theme_dir
+    # active_theme_dir = os.path.join(
+    #     dirpath, "..", "..", "themes", get_setting("ACTIVE_THEME")
+    # )
+    # module_blueprint.template_folder = active_theme_dir
 
     # return str(module_blueprint.template_folder)
-    return render_template("index.html")
+
+    return redirect(url_for("shop.homepage"))
+
